#!/bin/bash
#
# Copyright 2014 Aeneas Jaissle <aj@ajaissle.de>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 3 or, at your option, any later version
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin street, Fifth Floor, Boston, MA 02111-1301, USA.
#

if   [[ "$1" == "" ]]; then
    echo "Stopping cyrus.service"
    systemctl stop cyrus.service
    echo "Exit Code: $?"

    echo "Backing up /var/spool/imap..."
    tar cjvf $(hostname)-var-spool-imap_$(date --rfc-3339=date).tar.bz2 \
        --exclude=cyrus.squat \
        --exclude=cyrus.cache.NEW \
        --exclude=cyrus.expunge.NEW \
        --exclude=cyrus.index.NEW \
        /var/spool/imap
    echo "Exit Code: $?"

    echo "Backing up /var/lib/imap..."
    tar cjvf $(hostname)-var-lib-imap_$(date --rfc-3339=date).tar.bz2 \
        --exclude=/var/lib/imap/socket \
        --exclude=*.lock* \
        /var/lib/imap
    echo "Exit Code: $?"

    echo "Backing up /var/lib/sieve..."
    tar cjvf $(hostname)-var-lib-sieve_$(date --rfc-3339=date).tar.bz2 \
        /var/lib/sieve
    echo "Exit Code: $?"

    echo "Backing up mboxlist..."
    /usr/lib/cyrus/bin/ctl_mboxlist -d > $(hostname)-mboxlist_$(date --rfc-3339=date)
    echo "Exit Code: $?"

    echo "Starting cyrus.service"
    systemctl start cyrus.service
    echo "Exit Code: $?"

elif [[ "$1" == "--restore" ]]; then
    while : ; do
        if   [[ "$2" == "" ]]; then
            read -p "File to restore from: " input
        else
            if [[ -f "$2" ]]; then
                echo "Using $2 as restore source"
                input="$2"
            else
                echo "Please supply a valid and accessible backup file to restore from."
                read -p "File to restore from: " input
            fi
        fi
        if [[ -f "$input" ]]; then
            break
        fi
    done
    echo "Stopping cyrus.service"
    systemctl stop cyrus.service
    echo "Exit Code: $?"

    tar xjvf $input -C /
    echo "Exit Code: $?"

    #/usr/lib/cyrus/bin/ctl_mboxlist -u < mboxlist
    #/usr/lib/cyrus/bin/reconstruct -fr user/my.user@ajaissle.de

    echo "Starting cyrus.service"
    systemctl start cyrus.service
    echo "Exit Code: $?"

else
    echo "Option not recognized: $1"
fi
